window.Gleam.initSearch([{"doc":"chip","title":"chip","content":"# chip\n\n[![Package Version](https://img.shields.io/hexpm/v/chip)](https://hex.pm/packages/chip)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/chip/)\n\nA pure gleam process registry that plays along types and gleam OTP abstractions.\nWill automatically delist dead processes. \n\n## Example\n\n```gleam\nimport gleam/erlang/process\nimport chip\n\n// Names can be built out of any primitive or even types.\ntype Name {\n  A\n  B\n}\n\n// We can start the registry and register a new subject \nlet assert Ok(registry) = chip.start()\nchip.register(registry, A, process.new_subject())\n\n// If we lose scope of our processes, just look it up in the registry!\nlet assert Ok(subject) = chip.find(registry, A)\nlet assert Error(chip.NotFound) = chip.find(registry, B)\n```\n\nFeature-wise its still very basic but planning to integrate helpers\nfor supervisors that restar processes and a way to lookup name groups for\ndynamic dispatch.\n\n## Installation\n\nYou can If available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add chip\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/chip&gt;.\n","url":"index.html"},{"doc":"chip","title":"Errors","content":"pub type Errors {\n  NotFound\n}\n\nNotFound\n\n\nSynonyms:\nchip.Errors\nchip Errors","url":"chip.html#Errors"},{"doc":"chip","title":"Message","content":"pub opaque type Message(name, message)\n These are the possible messages that our registry can handle, this is an opaque\n type so you would use these commands through the equivalent functions.\n\nSynonyms:\nchip.Message\nchip Message","url":"chip.html#Message"},{"doc":"chip","title":"find","content":"pub fn find(registry: Subject(Message(a, b)), name: a) -&gt; Result(\n  Subject(b),\n  Errors,\n)\n Looks up a subject through its given name.\n \n ### Example\n \n \n &gt; chip.find(reigstry, &quot;MyProcess&quot;) \n Ok(subject)\n \nSynonyms:\nchip.find\nchip find","url":"chip.html#find"},{"doc":"chip","title":"register","content":"pub fn register(registry: Subject(Message(a, b)), name: a, subject: Subject(\n    b,\n  )) -&gt; Nil\n Manually registers a `Subject` within the registry.\n \n ## Example\n \n \n &gt; chip.register(registry, &quot;MyProcess&quot;, process.new_subject())\n Nil\n \nSynonyms:\nchip.register\nchip register","url":"chip.html#register"},{"doc":"chip","title":"start","content":"pub fn start() -&gt; Result(Subject(Message(a, b)), StartError)\n Starts our registry.\n \n ## Example\n \n \n &gt; chip.start()\n Ok(registry)\n \nSynonyms:\nchip.start\nchip start","url":"chip.html#start"},{"doc":"chip","title":"unregister","content":"pub fn unregister(registry: Subject(Message(a, b)), name: a) -&gt; Nil\n Manually unregister a `Subject` within the registry.\n \n ## Example\n \n \n &gt; chip.unregister(registry, &quot;MyProcess&quot;)\n Nil\n \nSynonyms:\nchip.unregister\nchip unregister","url":"chip.html#unregister"},{"doc":"chip","title":"chip","content":" A pure gleam process registry that plays along types and gleam OTP abstractions.\n Will automatically delist dead processes. \n \n ## Example\n \n ```gleam\n import gleam/erlang/process\n import chip\n \n // Names can be built out of any primitive or even types.\n type Name {\n   A\n   B\n }\n\n // We can start the registry and register a new subject \n let assert Ok(registry) = chip.start()\n chip.register(registry, A, process.new_subject())\n \n // If we lose scope of our processes, just look it up in the registry!\n let assert Ok(subject) = chip.find(registry, A)\n let assert Error(chip.NotFound) = chip.find(registry, B)\n ```","url":"chip.html"}]);